==> jc-1.4.0.tar.gz: java/security/DigestOutputStream.h <==
// public class java.security.DigestOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bcfbaafcc4fe454e java_security_DigestOutputStream

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_java_security_DigestOutputStream_H_
#define _JC_java_security_DigestOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_MessageDigest$object;

// Typedefs
typedef struct _jc_java_security_DigestOutputStream$sub_refs	_jc_java_security_DigestOutputStream$sub_refs;
typedef struct _jc_java_security_DigestOutputStream$sub_nonrefs	_jc_java_security_DigestOutputStream$sub_nonrefs;
typedef struct _jc_java_security_DigestOutputStream$refs	_jc_java_security_DigestOutputStream$refs;
typedef struct _jc_java_security_DigestOutputStream$nonrefs	_jc_java_security_DigestOutputStream$nonrefs;
typedef struct _jc_java_security_DigestOutputStream$object	_jc_java_security_DigestOutputStream$object;

typedef const struct _jc_java_security_DigestOutputStream$vmethods	_jc_java_security_DigestOutputStream$vmethods;
typedef const struct _jc_java_security_DigestOutputStream$vtable	_jc_java_security_DigestOutputStream$vtable;
typedef const struct _jc_java_security_DigestOutputStream$vtype	_jc_java_security_DigestOutputStream$vtype;

// Constructors
extern void _jc_java_security_DigestOutputStream$method$_init$98cc8abce28cab2b(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_java_security_MessageDigest$object *);

// Virtual methods
extern struct _jc_java_security_MessageDigest$object *_jc_java_security_DigestOutputStream$method$getMessageDigest$3b124d9f21254d6c(_jc_env *, struct _jc_java_security_DigestOutputStream$object *);
extern void _jc_java_security_DigestOutputStream$method$on$96b054f744a6b4c3(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, jboolean);
extern void _jc_java_security_DigestOutputStream$method$setMessageDigest$ea52511d9ace745c(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, struct _jc_java_security_MessageDigest$object *);
extern void _jc_java_security_DigestOutputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_DigestOutputStream$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_DigestOutputStream$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_DigestOutputStream$object *);
extern void _jc_java_security_DigestOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, jint);
extern void _jc_java_security_DigestOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_security_DigestOutputStream$method_info$getMessageDigest$3b124d9f21254d6c;
extern _jc_method _jc_java_security_DigestOutputStream$method_info$on$96b054f744a6b4c3;
extern _jc_method _jc_java_security_DigestOutputStream$method_info$setMessageDigest$ea52511d9ace745c;
extern _jc_method _jc_java_security_DigestOutputStream$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_java_security_DigestOutputStream$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_java_security_DigestOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_security_DigestOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_security_DigestOutputStream$vmethods {
	struct _jc_java_security_MessageDigest$object	*(*getMessageDigest$3b124d9f21254d6c)(_jc_env *, struct _jc_java_security_DigestOutputStream$object *);
	void	(*on$96b054f744a6b4c3)(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, jboolean);
	void	(*setMessageDigest$ea52511d9ace745c)(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, struct _jc_java_security_MessageDigest$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_DigestOutputStream$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_DigestOutputStream$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, jint);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_java_security_DigestOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_security_DigestOutputStream$vmethods	java_security_DigestOutputStream;
};

// Vtype
struct _jc_java_security_DigestOutputStream$vtype {
	_jc_type			type;
	_jc_java_security_DigestOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_DigestOutputStream$sub_refs {
	struct _jc_java_security_MessageDigest$object	*digest;
};

// Reference instance fields (object)
struct _jc_java_security_DigestOutputStream$refs {
    _jc_java_security_DigestOutputStream$sub_refs	java_security_DigestOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_DigestOutputStream$sub_nonrefs {
	jboolean	state;
};

// Non-reference instance fields (object)
struct _jc_java_security_DigestOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_security_DigestOutputStream$sub_nonrefs	java_security_DigestOutputStream;
};

// Object instance structure
struct _jc_java_security_DigestOutputStream$object {
	_jc_java_security_DigestOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_DigestOutputStream$vtype	*vtype;
	_jc_java_security_DigestOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_DigestOutputStream$vtype _jc_java_security_DigestOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_DigestOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_DigestOutputStream$class_object;

#endif	/* _JC_java_security_DigestOutputStream_H_ */

==> jc-1.4.6.tar.gz: java/security/DigestOutputStream.h <==
// public class java.security.DigestOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bcfbaafcc4fe454e java_security_DigestOutputStream

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_java_security_DigestOutputStream_H_
#define _JC_java_security_DigestOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_MessageDigest$object;

// Typedefs
typedef struct _jc_java_security_DigestOutputStream$sub_refs	_jc_java_security_DigestOutputStream$sub_refs;
typedef struct _jc_java_security_DigestOutputStream$sub_nonrefs	_jc_java_security_DigestOutputStream$sub_nonrefs;
typedef struct _jc_java_security_DigestOutputStream$refs	_jc_java_security_DigestOutputStream$refs;
typedef struct _jc_java_security_DigestOutputStream$nonrefs	_jc_java_security_DigestOutputStream$nonrefs;
typedef struct _jc_java_security_DigestOutputStream$object	_jc_java_security_DigestOutputStream$object;

typedef const struct _jc_java_security_DigestOutputStream$vmethods	_jc_java_security_DigestOutputStream$vmethods;
typedef const struct _jc_java_security_DigestOutputStream$vtable	_jc_java_security_DigestOutputStream$vtable;
typedef const struct _jc_java_security_DigestOutputStream$vtype	_jc_java_security_DigestOutputStream$vtype;

// Constructors
extern void _jc_java_security_DigestOutputStream$method$_init$98cc8abce28cab2b(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_java_security_MessageDigest$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_security_MessageDigest$object *_jc_java_security_DigestOutputStream$method$getMessageDigest$3b124d9f21254d6c(_jc_env *, struct _jc_java_security_DigestOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_DigestOutputStream$method$on$96b054f744a6b4c3(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_java_security_DigestOutputStream$method$setMessageDigest$ea52511d9ace745c(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, struct _jc_java_security_MessageDigest$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_DigestOutputStream$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_DigestOutputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_DigestOutputStream$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_DigestOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_DigestOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_security_DigestOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_DigestOutputStream$method_info$getMessageDigest$3b124d9f21254d6c;
extern _jc_method _jc_java_security_DigestOutputStream$method_info$on$96b054f744a6b4c3;
extern _jc_method _jc_java_security_DigestOutputStream$method_info$setMessageDigest$ea52511d9ace745c;
extern _jc_method _jc_java_security_DigestOutputStream$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_java_security_DigestOutputStream$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_java_security_DigestOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_security_DigestOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_security_DigestOutputStream$vmethods {
	struct _jc_java_security_MessageDigest$object	*(*getMessageDigest$3b124d9f21254d6c)(_jc_env *, struct _jc_java_security_DigestOutputStream$object *) _JC_JCNI_ATTR;
	void	(*on$96b054f744a6b4c3)(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, jboolean) _JC_JCNI_ATTR;
	void	(*setMessageDigest$ea52511d9ace745c)(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, struct _jc_java_security_MessageDigest$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_DigestOutputStream$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_DigestOutputStream$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_security_DigestOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_DigestOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_security_DigestOutputStream$vmethods	java_security_DigestOutputStream;
};

// Vtype
struct _jc_java_security_DigestOutputStream$vtype {
	_jc_type			type;
	_jc_java_security_DigestOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_DigestOutputStream$sub_refs {
	struct _jc_java_security_MessageDigest$object	*digest;
};

// Reference instance fields (object)
struct _jc_java_security_DigestOutputStream$refs {
    _jc_java_security_DigestOutputStream$sub_refs	java_security_DigestOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_DigestOutputStream$sub_nonrefs {
	jboolean	state;
};

// Non-reference instance fields (object)
struct _jc_java_security_DigestOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_security_DigestOutputStream$sub_nonrefs	java_security_DigestOutputStream;
};

// Object instance structure
struct _jc_java_security_DigestOutputStream$object {
	_jc_java_security_DigestOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_DigestOutputStream$vtype	*vtype;
	_jc_java_security_DigestOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_DigestOutputStream$vtype _jc_java_security_DigestOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_DigestOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_DigestOutputStream$class_object;

#endif	/* _JC_java_security_DigestOutputStream_H_ */
